@@ -30,7 +30,7 @@ from typing import Optional
 import click
 import psutil
 
-import covalent_dispatcher
+from covalent._shared_files.config import _config_manager as cm
 from covalent._shared_files.config import get_config, set_config
 
 DISPATCHER_PIDFILE = get_config("dispatcher.cache_dir") + "/dispatcher.pid"
@@ -127,6 +127,30 @@ def _next_available_port(requested_port: int) -> int:
     return assigned_port
 
 
+def _is_dispatcher_running() -> bool:
+    """Check status of dispatcher server.
+
+    Returns:
+        status: Status of whether the dispatcher server is running.
+    """
+
+    if _read_pid(DISPATCHER_PIDFILE) == -1:
+        return False
+    return True
+
+
+def _is_ui_running() -> bool:
+    """Check status of user interface (UI) server.
+
+    Returns:
+        status: Status of whether the user interface server is running.
+    """
+
+    if _read_pid(UI_PIDFILE) == -1:
+        return False
+    return True
+
+
 def _graceful_start(
     server_name: str,
     server_root: str,
@@ -381,16 +405,18 @@ def status() -> None:
 @click.command()
 def purge() -> None:
     """
-    Delete the cache and config settings.
+    Shutdown servers and delete the cache and config settings.
     """
 
+    # Shutdown UI and dispatcher server.
+    _graceful_shutdown("dispatcher", DISPATCHER_PIDFILE)
+    _graceful_shutdown("UI", UI_PIDFILE)
+
     shutil.rmtree(get_config("sdk.log_dir"), ignore_errors=True)
     shutil.rmtree(get_config("dispatcher.cache_dir"), ignore_errors=True)
     shutil.rmtree(get_config("dispatcher.log_dir"), ignore_errors=True)
     shutil.rmtree(get_config("user_interface.log_dir"), ignore_errors=True)
 
-    from covalent._shared_files.config import _config_manager as cm
-
     cm.purge_config()
 
     click.echo("Covalent server files have been purged.")
